#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hindent
version:              6.1.1
visibility:           public
id:                   hindent-6.1.1-709Cz5CfPCrE7Rtwr3ypr
key:                  hindent-6.1.1-709Cz5CfPCrE7Rtwr3ypr
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    See the GitHub page for usage \/ explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  b2463eb02dddc229909787085dda78c4
exposed:              True
exposed-modules:      HIndent
hidden-modules:
    HIndent.Applicative HIndent.ByteString HIndent.CabalFile
    HIndent.CodeBlock HIndent.CommandlineOptions HIndent.Config
    HIndent.Error HIndent.Fixity HIndent.GhcLibParserWrapper.GHC.Hs
    HIndent.Language HIndent.LanguageExtension
    HIndent.LanguageExtension.Conversion
    HIndent.LanguageExtension.Types HIndent.ModulePreprocessing
    HIndent.ModulePreprocessing.CommentRelocation HIndent.Parse
    HIndent.Path.Find HIndent.Pragma HIndent.Pretty
    HIndent.Pretty.Combinators HIndent.Pretty.Combinators.Comment
    HIndent.Pretty.Combinators.Getter HIndent.Pretty.Combinators.Indent
    HIndent.Pretty.Combinators.Lineup HIndent.Pretty.Combinators.Op
    HIndent.Pretty.Combinators.Outputable
    HIndent.Pretty.Combinators.RhsSeparator
    HIndent.Pretty.Combinators.String HIndent.Pretty.Combinators.Switch
    HIndent.Pretty.Combinators.Wrap HIndent.Pretty.Import
    HIndent.Pretty.Import.Sort HIndent.Pretty.NodeComments
    HIndent.Pretty.Pragma HIndent.Pretty.SigBindFamily
    HIndent.Pretty.Types HIndent.Printer Paths_hindent

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hindent-6.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hindent-6.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hindent-6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.1-709Cz5CfPCrE7Rtwr3ypr
depends:
    Cabal-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-9.6.6 ghc-lib-parser-ex-9.6.0.2-Jy1C7xZXqwfEpq8iK8HPgR
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    optparse-applicative-0.18.1.0-F2USUEHNufd3B1Lo6sWmKk
    path-0.9.6-7DlPI4eV5bF2D75WxJeaik
    path-io-1.8.2-Dr0It13TwFq2tugZgQ9i2M
    regex-tdfa-1.3.2.5-6VokBrH99ZuK2RS5akjMTl
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-45RHZbqQsU9HukQlnlXSjw
    transformers-0.6.1.0 unicode-show-0.1.1.1-C20pbUjEfoeKXypNLvLMXw
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    yaml-0.11.11.2-LmJ3lQubKx2LZPMJyshbOQ

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-hindent-z-hindent-internal
version:              6.1.1
package-name:         hindent
lib-name:             hindent-internal
id:                   hindent-6.1.1-5KQBltdtEsO5olyBkiNb4t-hindent-internal
key:                  hindent-6.1.1-5KQBltdtEsO5olyBkiNb4t-hindent-internal
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    See the GitHub page for usage \/ explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  9d0ae1d98d7850ae05addeb807155ca1
exposed-modules:      HIndent.Internal.Test.Markdone
hidden-modules:       Paths_hindent
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hindent-6.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hindent-6.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hindent-6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.1-5KQBltdtEsO5olyBkiNb4t-hindent-internal
depends:
    Cabal-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-lib-parser-ex-9.6.0.2-Jy1C7xZXqwfEpq8iK8HPgR
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    optparse-applicative-0.18.1.0-F2USUEHNufd3B1Lo6sWmKk
    path-0.9.6-7DlPI4eV5bF2D75WxJeaik
    path-io-1.8.2-Dr0It13TwFq2tugZgQ9i2M
    regex-tdfa-1.3.2.5-6VokBrH99ZuK2RS5akjMTl
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-45RHZbqQsU9HukQlnlXSjw
    transformers-0.6.1.0 unicode-show-0.1.1.1-C20pbUjEfoeKXypNLvLMXw
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    yaml-0.11.11.2-LmJ3lQubKx2LZPMJyshbOQ

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

